@@ -1,15 +1,6 @@
-import json
-
 import pytest
-from requests import Response, Request
 
-from pyfy.wrappers import (
-    _dispatch_request,
-    _inject_user_id,
-    _default_to_locale,
-    _set_and_get_me_attr_async,
-    _set_and_get_me_attr_sync,
-)
+from pyfy.wrappers import _set_and_get_me_attr_async, _set_and_get_me_attr_sync
 
 from pyfy import Spotify, UserCreds, AsyncSpotify
 
